@@ -13,9 +13,11 @@ def get_dir_hashes(path):
     for path, subdirs, files in os.walk(path):
         for name in list(sorted(files)):
             fname = os.path.join(path, name)
-            with open(fname, 'rb', encoding='utf-8') as file:
+            with open(fname, 'rb') as file:
                 data = file.read()
-                ans.append(hashlib.md5(data).hexdigest())
+                _hash = hashlib.md5(data).hexdigest()
+
+                ans.append(_hash)
     return ans
 
 
@@ -24,7 +26,6 @@ def check_2_libs_actual():
 
     global_fift_hashes = get_dir_hashes(os.path.abspath(f"{global_path}/fift-libs"))
     local_fift_hashes = get_dir_hashes(os.path.abspath(f"{local_path}/fift-libs"))
-
     global_func_hashes = get_dir_hashes(os.path.abspath(f"{global_path}/func-libs"))
     local_func_hashes = get_dir_hashes(os.path.abspath(f"{local_path}/func-libs"))
 
